@@ -108,7 +108,7 @@ QByteArray FBDialog::generatePostBody (const QHash<QString, QString>& aParams) c
     QString endLine = "\r\n--" + kStringBoundary + "\r\n", kStringBoundary;
 
     QString tmp = "--" + kStringBoundary + "\r\n";
-    body.append(tmp);
+    body.append(tmp.toUtf8());
 
 
     QHashIterator<QString, QString> i(aParams);
@@ -116,9 +116,9 @@ QByteArray FBDialog::generatePostBody (const QHash<QString, QString>& aParams) c
         i.next();
 
         tmp = "Content-Disposition: form-data; name=\"" + i.key().toUtf8() + "\"\r\n\r\n" ;
-        body.append(tmp);
+        body.append(tmp.toUtf8());
         body.append(i.value().toUtf8());
-        body.append(endLine);
+        body.append(endLine.toUtf8());
     }
 
     return body;
@@ -195,6 +195,10 @@ void FBDialog::loadURL(const QString& aUrl, QNetworkAccessManager::Operation aMe
     QUrl url (iLoadingUrl);
     QNetworkRequest request(url);
 
+#if QT_VERSION >= 0x040600
+    request.setAttribute(QNetworkRequest::HttpPipeliningAllowedAttribute, true);
+#endif
+
     if (aMethod == QNetworkAccessManager::PostOperation)
     {
         const QString contentType = "multipart/form-data; boundary=" + kStringBoundary;
